@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Sample objects for use in tests
-
-$Id: sampledm.py 113732 2010-06-21 15:31:11Z ctheune $
 """
 
 class DataManager(object):
@@ -405,8 +403,5 @@ class Rollback(object):
 
 
 def test_suite():
-    from zope.testing.doctest import DocTestSuite
+    from doctest import DocTestSuite
     return DocTestSuite()
-
-if __name__ == '__main__':
-    unittest.main()
